@@ -21,11 +21,13 @@ from typing import ClassVar
 
 from setuptools import Command
 
-from cx_Freeze._compat import IS_CONDA, PYTHON_VERSION
+from cx_Freeze._compat import IS_CONDA, IS_LINUX, PYTHON_VERSION
 from cx_Freeze.exception import ExecError, FileError, PlatformError
 
 __all__ = ["bdist_rpm"]
 
+logger = logging.getLogger(__name__)
+
 
 class bdist_rpm(Command):
     """Create an RPM distribution."""
@@ -202,11 +204,8 @@ class bdist_rpm(Command):
         self.debug = 0
 
     def finalize_options(self) -> None:
-        if os.name != "posix":
-            msg = (
-                "don't know how to create RPM "
-                f"distributions on platform {os.name}"
-            )
+        if not IS_LINUX:
+            msg = "bdist_rpm is supported only on Linux"
             raise PlatformError(msg)
 
         self._rpm = shutil.which("rpm")
@@ -323,7 +322,7 @@ class bdist_rpm(Command):
                 raise FileError(msg)
 
         # build package, binary only (-bb)
-        logging.info("building RPMs")
+        logger.info("building RPMs")
         rpm_cmd = [self._rpmbuild, "-bb"]
         if not self.keep_temp:
             rpm_cmd.append("--clean")
@@ -361,17 +360,14 @@ class bdist_rpm(Command):
 
         self.spawn(rpm_cmd)
 
-        if not self.dry_run:
-            for binary_rpm in binary_rpms:
-                rpm = os.path.join(rpm_dir["RPMS"], binary_rpm)
-                if os.path.exists(rpm):
-                    self.move_file(rpm, self.dist_dir)
-                    filename = os.path.join(
-                        self.dist_dir, os.path.basename(rpm)
-                    )
-                    self.distribution.dist_files.append(
-                        ("bdist_rpm", PYTHON_VERSION, filename)
-                    )
+        for binary_rpm in binary_rpms:
+            rpm = os.path.join(rpm_dir["RPMS"], binary_rpm)
+            if os.path.exists(rpm):
+                self.move_file(rpm, self.dist_dir)
+                filename = os.path.join(self.dist_dir, os.path.basename(rpm))
+                self.distribution.dist_files.append(
+                    ("bdist_rpm", PYTHON_VERSION, filename)
+                )
 
     def _make_spec_file(self) -> list[str]:
         """Generate the text of an RPM spec file and return it as a
