@@ -12,6 +12,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING
 
 from cx_Freeze._compat import IS_CONDA, IS_MACOS, IS_MINGW, IS_WINDOWS
+from cx_Freeze.hooks.global_names import CONCURRENT_FUTURES_GLOBAL_NAMES
 from cx_Freeze.hooks.qthooks import get_qt_plugins_paths  # noqa: F401
 
 if TYPE_CHECKING:
@@ -113,9 +114,19 @@ def load_charset_normalizer_md(finder: ModuleFinder, module: Module) -> None:
         finder.include_module("charset_normalizer.md__mypyc")
 
 
+def load_collections(finder: ModuleFinder, module: Module) -> None:
+    """Sets the alias for collections.abc."""
+    try:
+        finder.include_module("collections.abc")
+    except ImportError:
+        # collections.abc module does not exist in Python 3.13+
+        # >>> _sys.modules['collections.abc'] = _collections_abc
+        finder.add_alias("collections.abc", "_collections_abc")
+
+
 def load_concurrent_futures(finder: ModuleFinder, module: Module) -> None:
     """Ignore names that should not be confused with modules to be imported."""
-    module.global_names.update(["ProcessPoolExecutor", "ThreadPoolExecutor"])
+    module.global_names.update(CONCURRENT_FUTURES_GLOBAL_NAMES)
 
 
 def load_crc32c(finder: ModuleFinder, module: Module) -> None:
@@ -139,7 +150,10 @@ def load_cryptography(finder: ModuleFinder, module: Module) -> None:
 def load_ctypes_util(finder: ModuleFinder, module: Module) -> None:
     """The ctypes.util module should filter import names."""
     if not IS_MACOS:
+        finder.exclude_module("ctypes.macholib")
         module.ignore_names.add("ctypes.macholib.dyld")
+    if not sys.platform.startswith("aix"):
+        module.exclude_names.add("ctypes._aix")
 
 
 def load__ctypes(finder: ModuleFinder, module: Module) -> None:
@@ -155,6 +169,9 @@ def load__ctypes(finder: ModuleFinder, module: Module) -> None:
                     target = f"lib/{source.name}"
                     finder.lib_files[source] = target
                     finder.include_files(source, target)
+    # Python 3.14+
+    with suppress(ImportError):
+        finder.include_module("ctypes._layout")
 
 
 def load_cx_Oracle(finder: ModuleFinder, module: Module) -> None:
@@ -167,8 +184,6 @@ def load_cx_Oracle(finder: ModuleFinder, module: Module) -> None:
 
 def load_datetime(finder: ModuleFinder, module: Module) -> None:
     """Optimize datetime module."""
-    if not hasattr(sys, "stdlib_module_names"):  # py 3.9
-        return
     if "_pydatetime" in sys.stdlib_module_names:  # py 3.12+
         try:
             finder.include_module("_datetime")
@@ -199,13 +214,6 @@ def load_difflib(finder: ModuleFinder, module: Module) -> None:
     module.exclude_names.add("doctest")
 
 
-def load_docutils_frontend(finder: ModuleFinder, module: Module) -> None:
-    """The optik module is the old name for the optparse module; ignore the
-    module if it cannot be found.
-    """
-    module.ignore_names.add("optik")
-
-
 def load_flask_compress(finder: ModuleFinder, module: Module) -> None:
     """flask-compress requires its metadata."""
     module.update_distribution("Flask_Compress")
@@ -307,13 +315,6 @@ def load_jpype(finder: ModuleFinder, module: Module) -> None:
         )
 
 
-def load_lazy_loader(finder: ModuleFinder, module: Module) -> None:
-    """Use load_lazy_loader 0.2+ to work with .pyc files."""
-    if module.distribution.version < (0, 2):
-        msg = "Please upgrade 'lazy_loader>=0.2' to support cx_Freeze"
-        raise SystemExit(msg)
-
-
 def load_librosa(finder: ModuleFinder, module: Module) -> None:
     """The librosa must be loaded as package."""
     finder.include_package("librosa")
@@ -414,14 +415,6 @@ def load_pycountry(finder: ModuleFinder, module: Module) -> None:
     module.in_file_system = 1
 
 
-def load_pycparser(finder: ModuleFinder, module: Module) -> None:
-    """These files are missing which causes
-    permission denied issues on windows when they are regenerated.
-    """
-    finder.include_module("pycparser.lextab")
-    finder.include_module("pycparser.yacctab")
-
-
 def load_pyodbc(finder: ModuleFinder, module: Module) -> None:
     """The pyodbc module implicitly imports others modules;
     make sure this happens.
@@ -478,46 +471,6 @@ def load_pywintypes(finder: ModuleFinder, module: Module) -> None:
     )
 
 
-def load_re(finder: ModuleFinder, module: Module) -> None:
-    """Ignore names that should not be confused with modules to be imported."""
-    if module.path:  # package since Python 3.11
-        module.global_names.update(
-            [
-                "match",
-                "fullmatch",
-                "search",
-                "sub",
-                "subn",
-                "split",
-                "findall",
-                "finditer",
-                "compile",
-                "purge",
-                "escape",
-                "error",
-                "Pattern",
-                "Match",
-                "A",
-                "I",
-                "L",
-                "M",
-                "S",
-                "X",
-                "U",
-                "ASCII",
-                "IGNORECASE",
-                "LOCALE",
-                "MULTILINE",
-                "DOTALL",
-                "VERBOSE",
-                "UNICODE",
-                "NOFLAG",
-                "RegexFlag",
-                "PatternError",
-            ]
-        )
-
-
 def load_reportlab(finder: ModuleFinder, module: Module) -> None:
     """The reportlab module loads a submodule rl_settings via exec so force
     its inclusion here.
@@ -575,16 +528,6 @@ def load_time(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("_strptime")
 
 
-def load_tokenizers(finder: ModuleFinder, module: Module) -> None:
-    """On Linux the tokenizers.libs directory is not copied."""
-    if module.path is None:
-        return
-    libs_name = "tokenizers.libs"
-    source_dir = module.path[0].parent / libs_name
-    if source_dir.exists():
-        finder.include_files(source_dir, Path("lib", libs_name))
-
-
 def load_typing(finder: ModuleFinder, module: Module) -> None:
     """Optimize typing module."""
     finder.add_alias("typing.io", "io")
@@ -637,14 +580,11 @@ def load_win32file(finder: ModuleFinder, module: Module) -> None:
     finder.include_module("win32timezone")
 
 
-def load_wx_lib_pubsub_core(finder: ModuleFinder, module: Module) -> None:
-    """The wx.lib.pubsub.core module modifies the search path which cannot
-    be done in a frozen application in the same way; modify the module
-    search path here instead so that the right modules are found; note
-    that this only works if the import of wx.lib.pubsub.setupkwargs
-    occurs first.
+def load_win32print(finder: ModuleFinder, module: Module) -> None:
+    """The win32print module implicitly loads the pywintypes module;
+    make sure this happens.
     """
-    module.path.insert(0, module.file.parent / "kwargs")
+    finder.include_module("pywintypes")
 
 
 def load_xml_etree_cElementTree(finder: ModuleFinder, module: Module) -> None:
@@ -679,13 +619,6 @@ def load_zlib(finder: ModuleFinder, module: Module) -> None:
             finder.include_files(source, target)
 
 
-def load_zope_component(finder: ModuleFinder, module: Module) -> None:
-    """The zope.component package requires the presence of the pkg_resources
-    module but it uses a dynamic, not static import to do its work.
-    """
-    finder.include_module("pkg_resources")
-
-
 #
 # missing section
 #
@@ -708,3 +641,10 @@ def missing_ltihooks(finder: ModuleFinder, caller: Module) -> None:
 def missing_six_moves(finder: ModuleFinder, caller: Module) -> None:
     """The six module creates fake modules."""
     caller.ignore_names.add("six.moves")
+
+
+def missing_typing_extensions(finder: ModuleFinder, caller: Module) -> None:
+    """The typing_extensions module is not required at runtime, so ignore it
+    when it cannot be found.
+    """
+    caller.ignore_names.add("typing_extensions")
