@@ -1,14 +1,11 @@
-"""Example for aiohttp.web basic server
-"""
-
-from __future__ import annotations
+"""Example for aiohttp.web basic server."""
 
 import textwrap
 
 from aiohttp import web
 
 
-async def intro(request):
+async def intro(request: web.Request) -> web.StreamResponse:
     txt = textwrap.dedent(
         """\
         Type {url}/hello/John  {url}/simple or {url}/change_body
@@ -24,18 +21,20 @@ async def intro(request):
     return resp
 
 
-async def simple(request):
+async def simple(request: web.Request) -> web.StreamResponse:  # noqa: ARG001
     return web.Response(text="Simple answer")
 
 
-async def change_body(request):
+async def change_body(
+    request: web.Request,  # noqa: ARG001
+) -> web.StreamResponse:
     resp = web.Response()
     resp.body = b"Body changed"
     resp.content_type = "text/plain"
     return resp
 
 
-async def hello(request):
+async def hello(request: web.Request) -> web.StreamResponse:
     resp = web.StreamResponse()
     name = request.match_info.get("name", "Anonymous")
     answer = ("Hello, " + name).encode("utf8")
@@ -47,7 +46,7 @@ async def hello(request):
     return resp
 
 
-def init():
+def init() -> web.Application:
     app = web.Application()
     app.router.add_get("/", intro)
     app.router.add_get("/simple", simple)
