@@ -7,9 +7,7 @@ environment in which the script runs
 Run the build process by running the command 'python setup.py bdist_msi'
 """
 
-from cx_Freeze import Executable, setup
-
-executables = [Executable("hello.py")]
+from cx_Freeze import setup
 
 bdist_msi_options = {
     "license_file": "LICENSE.rtf",
@@ -19,7 +17,7 @@ setup(
     name="hello",
     version="0.1",
     description="Sample cx_Freeze script to test MSI summary data stream",
-    executables=executables,
+    executables=["hello.py"],
     options={
         "build_exe": {"excludes": ["tkinter"]},
         "bdist_msi": bdist_msi_options,
