@@ -4,8 +4,6 @@ from __future__ import annotations
 
 import pytest
 
-TIMEOUT = 15
-
 zip_packages = pytest.mark.parametrize(
     "zip_packages", [False, True], ids=["", "zip_packages"]
 )
@@ -21,7 +19,8 @@ pyproject.toml
     name = "test_setuptools"
     version = "0.1.2.3"
     dependencies = [
-        "setuptools==78.1.1;python_version < '3.12'",
+        "setuptools==78.1.1;python_version == '3.10'",
+        "setuptools==80.9.0;python_version == '3.11'",
         "setuptools;python_version >= '3.12'",
     ]
 
@@ -45,8 +44,9 @@ def test_setuptools(tmp_package, zip_packages: bool) -> None:
         buf = pyproject.read_bytes().decode().splitlines()
         buf += ['zip_include_packages = "*"', 'zip_exclude_packages = ""']
         pyproject.write_bytes("\n".join(buf).encode("utf_8"))
+    tmp_package.install_dependencies()
     tmp_package.freeze()
     executable = tmp_package.executable("test_setuptools")
     assert executable.is_file()
-    result = tmp_package.run(executable, timeout=TIMEOUT)
+    result = tmp_package.run(executable)
     result.stdout.fnmatch_lines(["Hello from cx_Freeze", "Hello setuptools*"])
