@@ -31,5 +31,5 @@ def test___main__(tmp_package) -> None:
     file_created = tmp_package.executable_in_dist("test")
     assert file_created.is_file(), f"file not found: {file_created}"
 
-    result = tmp_package.run(file_created, timeout=10)
+    result = tmp_package.run(file_created)
     result.stdout.fnmatch_lines("Hello from cx_Freeze")
